@@ -21,8 +21,10 @@
 
 #include <libtracker-common/tracker-utils.h>
 #include <libtracker-common/tracker-ontologies.h>
+#include <libtracker-common/tracker-locale.h>
 
 #include "tracker-miner-applications.h"
+#include "tracker-miner-applications-locale.h"
 
 #ifdef HAVE_MEEGOTOUCH
 #include "tracker-miner-applications-meego.h"
@@ -35,9 +37,10 @@
 #define SOFTWARE_CATEGORY_URN_PREFIX "urn:software-category:"
 #define THEME_ICON_URN_PREFIX        "urn:theme-icon:"
 
-static void     miner_applications_finalize                (GObject              *object);
-static void     miner_applications_constructed             (GObject              *object);
-
+static void     miner_applications_initable_iface_init     (GInitableIface       *iface);
+static gboolean miner_applications_initable_init           (GInitable            *initable,
+                                                            GCancellable         *cancellable,
+                                                            GError              **error);
 static gboolean miner_applications_check_file              (TrackerMinerFS       *fs,
                                                             GFile                *file);
 static gboolean miner_applications_check_directory         (TrackerMinerFS       *fs,
@@ -66,17 +69,17 @@ struct ProcessApplicationData {
 	gchar *type;
 };
 
-G_DEFINE_TYPE (TrackerMinerApplications, tracker_miner_applications, TRACKER_TYPE_MINER_FS)
+static GInitableIface* miner_applications_initable_parent_iface;
+
+G_DEFINE_TYPE_WITH_CODE (TrackerMinerApplications, tracker_miner_applications, TRACKER_TYPE_MINER_FS,
+                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
+                                                miner_applications_initable_iface_init));
 
 static void
 tracker_miner_applications_class_init (TrackerMinerApplicationsClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	TrackerMinerFSClass *miner_fs_class = TRACKER_MINER_FS_CLASS (klass);
 
-	object_class->finalize = miner_applications_finalize;
-	object_class->constructed = miner_applications_constructed;
-
 	miner_fs_class->check_file = miner_applications_check_file;
 	miner_fs_class->check_directory = miner_applications_check_directory;
 	miner_fs_class->monitor_directory = miner_applications_monitor_directory;
@@ -92,33 +95,48 @@ tracker_miner_applications_init (TrackerMinerApplications *ma)
 }
 
 static void
-miner_applications_finalize (GObject *object)
+miner_applications_initable_iface_init (GInitableIface *iface)
 {
-	G_OBJECT_CLASS (tracker_miner_applications_parent_class)->finalize (object);
+	miner_applications_initable_parent_iface = g_type_interface_peek_parent (iface);
+	iface->init = miner_applications_initable_init;
 }
 
-static void
-miner_applications_constructed (GObject *object)
+static gboolean
+miner_applications_initable_init (GInitable     *initable,
+                                  GCancellable  *cancellable,
+                                  GError       **error)
 {
+	TrackerMinerApplications *ma;
+	TrackerMinerFS *fs;
 	GFile *file;
+	GError *inner_error = NULL;
 
-	G_OBJECT_CLASS (tracker_miner_applications_parent_class)->constructed (object);
+	ma = TRACKER_MINER_APPLICATIONS (initable);
+	fs = TRACKER_MINER_FS (initable);
+
+	/* Chain up parent's initable callback before calling child's one */
+	if (!miner_applications_initable_parent_iface->init (initable, cancellable, &inner_error)) {
+		g_propagate_error (error, inner_error);
+		return FALSE;
+	}
 
 	file = g_file_new_for_path ("/usr/share/applications/");
-	tracker_miner_fs_directory_add (TRACKER_MINER_FS (object), file, TRUE);
+	tracker_miner_fs_directory_add (fs, file, TRUE);
 	g_object_unref (file);
 
 	file = g_file_new_for_path ("/usr/share/desktop-directories/");
-	tracker_miner_fs_directory_add (TRACKER_MINER_FS (object), file, TRUE);
+	tracker_miner_fs_directory_add (fs, file, TRUE);
 	g_object_unref (file);
 
 #ifdef HAVE_MEEGOTOUCH
 	file = g_file_new_for_path ("/usr/lib/duicontrolpanel/");
-	tracker_miner_fs_directory_add (TRACKER_MINER_FS (object), file, TRUE);
+	tracker_miner_fs_directory_add (fs, file, TRUE);
 	g_object_unref (file);
 #endif /* HAVE_MEEGOTOUCH */
 
 	/* FIXME: Check XDG_DATA_DIRS and also process applications in there */
+
+	return TRUE;
 }
 
 static void
@@ -127,12 +145,18 @@ insert_data_from_desktop_file (TrackerSparqlBuilder *sparql,
                                const gchar          *metadata_key,
                                GKeyFile             *desktop_file,
                                const gchar          *key,
-                               gboolean              use_locale)
+                               const gchar          *locale)
 {
 	gchar *str;
 
-	if (use_locale) {
-		str = g_key_file_get_locale_string (desktop_file, GROUP_DESKTOP_ENTRY, key, NULL, NULL);
+	if (locale) {
+		/* Try to get the key with our desired LANG locale... */
+		str = g_key_file_get_locale_string (desktop_file, GROUP_DESKTOP_ENTRY, key, locale, NULL);
+		/* If our desired locale failed, use the list of LANG locales prepared by GLib
+		 * (will return untranslated string if none of the locales available) */
+		if (!str) {
+			str = g_key_file_get_locale_string (desktop_file, GROUP_DESKTOP_ENTRY, key, NULL, NULL);
+		}
 	} else {
 		str = g_key_file_get_string (desktop_file, GROUP_DESKTOP_ENTRY, key, NULL);
 	}
@@ -290,6 +314,7 @@ process_desktop_file (ProcessApplicationData  *data,
 	gsize cats_len;
 	gboolean is_software = TRUE;
 	const gchar *parent_urn;
+	gchar *lang;
 #ifdef HAVE_MEEGOTOUCH
 	gchar *logical_id = NULL;
 	gchar *translation_catalog = NULL;
@@ -301,11 +326,16 @@ process_desktop_file (ProcessApplicationData  *data,
 
 	path = g_file_get_path (data->file);
 
-	/* Try to get the categories with locale, then without if that fails */
-	cats = g_key_file_get_locale_string_list (key_file, GROUP_DESKTOP_ENTRY, "Categories", NULL, &cats_len, NULL);
+	/* Retrieve LANG locale setup */
+	lang = tracker_locale_get (TRACKER_LOCALE_LANGUAGE);
 
-	if (!cats)
-		cats = g_key_file_get_string_list (key_file, GROUP_DESKTOP_ENTRY, "Categories", &cats_len, NULL);
+	/* Try to get the categories with our desired LANG locale... */
+	cats = g_key_file_get_locale_string_list (key_file, GROUP_DESKTOP_ENTRY, "Categories", lang, &cats_len, NULL);
+	if (!cats) {
+		/* If our desired locale failed, use the list of LANG locales prepared by GLib
+		 * (will return untranslated string if none of the locales available) */
+		cats = g_key_file_get_locale_string_list (key_file, GROUP_DESKTOP_ENTRY, "Categories", NULL, &cats_len, NULL);
+	}
 
 	/* NOTE: We sanitize categories later on when iterating them */
 
@@ -323,12 +353,13 @@ process_desktop_file (ProcessApplicationData  *data,
 #endif /* HAVE_MEEGOTOUCH */
 
 	if (!name) {
-		/* Try to get the name with locale, then without if that fails */
-		name = g_key_file_get_locale_string (key_file, GROUP_DESKTOP_ENTRY, "Name", NULL, NULL);
-	}
-
-	if (!name) {
-		name = g_key_file_get_string (key_file, GROUP_DESKTOP_ENTRY, "Name", NULL);
+		/* Try to get the name with our desired LANG locale... */
+		name = g_key_file_get_locale_string (key_file, GROUP_DESKTOP_ENTRY, "Name", lang, NULL);
+		if (!name) {
+			/* If our desired locale failed, use the list of LANG locales prepared by GLib
+			 * (will return untranslated string if none of the locales available) */
+			name = g_key_file_get_locale_string (key_file, GROUP_DESKTOP_ENTRY, "Name", NULL, NULL);
+		}
 	}
 
 	/* Sanitize name */
@@ -456,9 +487,25 @@ process_desktop_file (ProcessApplicationData  *data,
 		tracker_sparql_builder_object (sparql, "nfo:SoftwareApplication");
 		tracker_sparql_builder_object (sparql, "nie:DataObject");
 
-		g_debug ("Invalid desktop file:'%s'", uri);
-		g_debug ("  Type '%s' is not part of the desktop file specification (expected 'Application', 'Link' or 'Directory')", type);
-		g_debug ("  Defaulting to 'Application'");
+		tracker_sparql_builder_predicate (sparql, "nie:dataSource");
+		tracker_sparql_builder_object_iri (sparql, APPLICATION_DATASOURCE_URN);
+
+		if (name) {
+			/* If we got a name, then the issue comes from the type.
+			 * As we're defaulting to Application here, we just g_debug() the problem. */
+			g_debug ("Invalid desktop file: '%s'", uri);
+			g_debug ("  Type '%s' is not part of the desktop file specification (expected 'Application', 'Link' or 'Directory')", type);
+			g_debug ("  Defaulting to 'Application'");
+		} else {
+			/* If we didn't get a name, the problem is more severe as we don't default it
+			 * to anything, so we g_warning() it.  */
+			g_warning ("Invalid desktop file: '%s'", uri);
+#ifdef HAVE_MEEGOTOUCH
+			g_warning ("  Couldn't get name, missing or wrong key (X-MeeGo-Logical-Id, X-MeeGo-Translation-Catalog or Name)");
+#else
+			g_warning ("  Couldn't get name, missing key (Name)");
+#endif
+		}
 	}
 
 	if (sparql && uri) {
@@ -477,18 +524,30 @@ process_desktop_file (ProcessApplicationData  *data,
 		   tracker_sparql_builder_predicate (sparql, "tracker:available");
 		   tracker_sparql_builder_object_boolean (sparql, TRUE); */
 
-		tracker_sparql_builder_predicate (sparql, "nie:title");
-		tracker_sparql_builder_object_string (sparql, name);
+		/* We should always always have a proper name if the desktop file is correct
+		 * w.r.t to the Meego or Freedesktop specs, but sometimes this is not true,
+		 * so instead of passing wrong stuff to the SPARQL builder, we avoid it.
+		 * If we don't have a proper name, we already warned it before. */
+		if (name) {
+			tracker_sparql_builder_predicate (sparql, "nie:title");
+			tracker_sparql_builder_object_string (sparql, name);
+		}
 
 		if (is_software) {
 			gchar *icon;
 
-			insert_data_from_desktop_file (sparql, uri,
-			                               TRACKER_NIE_PREFIX "comment", key_file,
-			                               "Comment", TRUE);
-			insert_data_from_desktop_file (sparql, uri,
-			                               TRACKER_NFO_PREFIX "softwareCmdLine", key_file,
-			                               "Exec", TRUE);
+			insert_data_from_desktop_file (sparql,
+			                               uri,
+			                               TRACKER_NIE_PREFIX "comment",
+			                               key_file,
+			                               "Comment",
+			                               lang);
+			insert_data_from_desktop_file (sparql,
+			                               uri,
+			                               TRACKER_NFO_PREFIX "softwareCmdLine",
+			                               key_file,
+			                               "Exec",
+			                               lang);
 
 			icon = g_key_file_get_string (key_file, GROUP_DESKTOP_ENTRY, "Icon", NULL);
 
@@ -551,10 +610,6 @@ process_desktop_file (ProcessApplicationData  *data,
 			}
 		}
 
-		tracker_sparql_builder_subject_iri (sparql, uri);
-		tracker_sparql_builder_predicate (sparql, "nie:dataSource");
-		tracker_sparql_builder_object_iri (sparql, APPLICATION_DATASOURCE_URN);
-
 		filename = g_filename_display_basename (path);
 		tracker_sparql_builder_predicate (sparql, "nfo:fileName");
 		tracker_sparql_builder_object_string (sparql, filename);
@@ -596,6 +651,7 @@ process_desktop_file (ProcessApplicationData  *data,
 	g_free (uri);
 	g_free (path);
 	g_free (name);
+	g_free (lang);
 }
 
 static void
@@ -706,10 +762,115 @@ miner_applications_process_file_attributes (TrackerMinerFS       *fs,
 	return FALSE;
 }
 
-TrackerMiner *
-tracker_miner_applications_new (void)
+/* If a reset is requested, we will remove from the store all items previously
+ * inserted by the tracker-miner-applications, this is:
+ *  (a) all elements which are nfo:softwareIcon of a given nfo:Software
+ *  (b) all nfo:Software in our graph (includes both applications and maemo applets)
+ *  (c) all elements which are nfo:softwareCategoryIcon of a given nfo:SoftwareCategory
+ *  (d) all nfo:SoftwareCategory in our graph
+ */
+static void
+miner_applications_reset (TrackerMiner *miner)
 {
-	return g_object_new (TRACKER_TYPE_MINER_APPLICATIONS,
-	                     "name", "Applications",
-	                     NULL);
+	GError *error = NULL;
+	TrackerSparqlBuilder *sparql;
+
+	sparql = tracker_sparql_builder_new_update ();
+
+	/* (a) all elements which are nfo:softwareIcon of a given nfo:Software */
+	tracker_sparql_builder_delete_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_subject_variable (sparql, "icon");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "rdfs:Resource");
+	tracker_sparql_builder_delete_close (sparql);
+
+	tracker_sparql_builder_where_open (sparql);
+	tracker_sparql_builder_subject_variable (sparql, "software");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "nfo:Software");
+	tracker_sparql_builder_subject_variable (sparql, "icon");
+	tracker_sparql_builder_predicate (sparql, "nfo:softwareIcon");
+	tracker_sparql_builder_object_variable (sparql, "software");
+	tracker_sparql_builder_where_close (sparql);
+
+	/* (b) all nfo:Software in our graph (includes both applications and maemo applets) */
+	tracker_sparql_builder_delete_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_subject_variable (sparql, "software");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "rdfs:Resource");
+	tracker_sparql_builder_delete_close (sparql);
+
+	tracker_sparql_builder_where_open (sparql);
+	tracker_sparql_builder_subject_variable (sparql, "software");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "nfo:Software");
+	tracker_sparql_builder_where_close (sparql);
+
+	/* (c) all elements which are nfo:softwareCategoryIcon of a given nfo:SoftwareCategory */
+	tracker_sparql_builder_delete_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_subject_variable (sparql, "icon");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "rdfs:Resource");
+	tracker_sparql_builder_delete_close (sparql);
+
+	tracker_sparql_builder_where_open (sparql);
+	tracker_sparql_builder_subject_variable (sparql, "category");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "nfo:SoftwareCategory");
+	tracker_sparql_builder_subject_variable (sparql, "icon");
+	tracker_sparql_builder_predicate (sparql, "nfo:softwareCategoryIcon");
+	tracker_sparql_builder_object_variable (sparql, "category");
+	tracker_sparql_builder_where_close (sparql);
+
+	/* (d) all nfo:SoftwareCategory in our graph */
+	tracker_sparql_builder_delete_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_subject_variable (sparql, "category");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "rdfs:Resource");
+	tracker_sparql_builder_delete_close (sparql);
+
+	tracker_sparql_builder_where_open (sparql);
+	tracker_sparql_builder_subject_variable (sparql, "category");
+	tracker_sparql_builder_predicate (sparql, "a");
+	tracker_sparql_builder_object (sparql, "nfo:SoftwareCategory");
+	tracker_sparql_builder_where_close (sparql);
+
+	/* Execute a sync update, we don't want the apps miner to start before
+	 * we finish this. */
+	tracker_sparql_connection_update (tracker_miner_get_connection (miner),
+	                                  tracker_sparql_builder_get_result (sparql),
+	                                  G_PRIORITY_HIGH,
+	                                  NULL,
+	                                  &error);
+
+	if (error) {
+		/* Some error happened performing the query, not good */
+		g_critical ("Couldn't reset mined applications: %s",
+		            error ? error->message : "unknown error");
+		g_error_free (error);
+	}
+
+	g_object_unref (sparql);
+}
+
+TrackerMiner *
+tracker_miner_applications_new (GError **error)
+{
+	TrackerMiner *miner;
+
+	miner = g_initable_new (TRACKER_TYPE_MINER_APPLICATIONS,
+	                        NULL,
+	                        error,
+	                        "name", "Applications",
+	                        NULL);
+	if (miner &&
+	    tracker_miner_applications_locale_changed ()) {
+		/* Before returning the newly created miner, check if we need
+		 * to reset it */
+		g_message ("Locale change detected, so resetting miner to "
+		           "remove all previously created items...");
+		miner_applications_reset (miner);
+	}
+
+	return miner;
 }
